@@ -1,5 +1,5 @@
 package Kayako::RestAPI;
-$Kayako::RestAPI::VERSION = '0.04';
+$Kayako::RestAPI::VERSION = '0.05';
 
 # ABSTRACT: Perl library for working with L<Kayako REST API|https://kayako.atlassian.net/wiki/display/DEV/Kayako+REST+API>. Tested with
 
@@ -7,6 +7,7 @@ $Kayako::RestAPI::VERSION = '0.04';
 use common::sense;
 use Mojo::UserAgent;
 use Digest::SHA qw(hmac_sha256_base64);
+use File::Slurp;
 use XML::XML2JSON;
 use utf8;
 use Data::Dumper;
@@ -194,6 +195,64 @@ sub get_staff {
     $self->xml2obj($xml)->{staffusers}{staff};    # array
 }
 
+# HTTP mocks
+# perl -Ilib -MData::Dumper -MKayako::RestAPI -E 'print Dumper Kayako::RestAPI::_samples();'
+sub _samples {
+    return [
+        {
+            method      => 'get',
+            route       => '/Tickets/Ticket/1000/',
+            sample_file => 'ticket.xml',
+            params      => {}
+        },
+        {
+            method      => 'get',
+            route       => '/Base/Department/',
+            sample_file => 'departments.xml'
+        },
+        {
+            method      => 'get',
+            route       => '/Tickets/TicketStatus/',
+            sample_file => 'ticket_status.xml'
+        },
+        {
+            method      => 'get',
+            route       => '/Tickets/TicketPriority/',
+            sample_file => 'ticket_priority.xml'
+        },
+        {
+            method      => 'get',
+            route       => '/Tickets/TicketType/',
+            sample_file => 'ticket_type.xml'
+        },
+        {
+            method      => 'get',
+            route       => '/Base/Staff/',
+            sample_file => 'staff.xml'
+        }
+    ];
+}
+
+# generate ethalon data to t/lib/Kayako/samples
+# perl -Ilib -MData::Dumper -MKayako::RestAPI -E 'print Dumper Kayako::RestAPI::_generate_t_samples();'
+sub _generate_t_samples {
+    my @samples = @{ __PACKAGE__->_samples };
+    my $k       = Kayako::RestAPI->new(
+        {
+            api_url    => '',
+            api_key    => '',
+            secret_key => ''
+        }
+    );
+
+    for my $s (@samples) {
+        my $data = $k->_query( $s->{method}, $s->{route} );
+        write_file( 't/lib/Kayako/samples/' . $s->{sample_file},
+            { binmode => ':raw' }, $data );
+    }
+
+}
+
 1;
 
 __END__
@@ -208,7 +267,7 @@ Kayako::RestAPI - Perl library for working with L<Kayako REST API|https://kayako
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -406,7 +465,7 @@ E.g.
             'lastname' => { 'text' => 'Serikov' },
             'enabledst' => { 'text' => '0'},
             'username' => { 'text' => 'pavelsr' },
-            'isenabled' => { 'text' => '1' }6,
+            'isenabled' => { 'text' => '1' },
             'staffgroupid' => { 'text' => '4' },
             'greeting' => {},
             'timezone' => {},
